@@ -265,7 +265,7 @@ class SDSSLogger(logging.Logger):
                 handler.setLevel(level)
 
 
-def get_logger(name, **kwargs):
+def get_logger(name, **kwargs) -> SDSSLogger:
     """Gets a new logger."""
 
     orig_logger = logging.getLoggerClass()
